%define product_family Amazon Linux
%define dist_tag amzn
%define dist_version 2023
%define codename Amazon Linux

%define major 2023
# make sure olways verride 
%define minor 99
%define release 20990101
%define revision 0

%global dist .%{dist_tag}%{dist_version}xwalker

%define cpe cpe:2.3:o:amazon:amazon_linux:%{dist_version}

# Fedora upstream
%define upstream_version 34

Summary:        %{product_family} release files
Name:           system-release
Version:        %{major}.%{minor}.%{release}
Release:        %{revision}%{dist}
License:        MIT
URL:            https://amazonlinux.com/

# systemd preset files (via upstream)
Source10:       85-display-manager.preset
Source11:       90-default.preset
Source12:       90-default-user.preset
Source13:       99-default-disable.preset
# systemd preset files (amzn)
Source14:       91-update-motd.preset
Source15:       91-amazon-ssm-agent.preset
Source16:       91-hibinit-agent.preset
Source17:       91-systemd-networkd.preset

# amazon linux repo access via CloudFront
Source20:       amazonlinux.repo-cdn
Source21:       release-notification.conf-cdn

# amazon linux repo access via S3
Source22:       amazonlinux.repo-s3
Source23:       release-notification.conf-s3

# Kernel Livepatch Repo (CDN, S3)
Source24:       kernel-livepatch.repo-cdn
Source25:       kernel-livepatch.repo-s3

# Signing key
Source30:       RPM-GPG-KEY-amazon-linux-2022
Source31:       RPM-GPG-KEY-amazon-linux-2023
# update-motd scripts
Source40:       30-banner
Source41:       70-available-updates

# cloud-init configuration
Source50:       10_aws_dnfvars.cfg

BuildArch:      noarch
Provides:       system-release(%{dist_version})
Requires:       amazon-linux-repo(%{dist_version})
Suggests:       amazon-linux-repo-cdn
Suggests:       kernel-livepatch-repo kernel-livepatch-repo-cdn

%description
%{product_family} release files

%package -n amazon-linux-repo-cdn
Summary: Access to Amazon Linux repositories via CloudFront
Provides: amazon-linux-repo
Provides: amazon-linux-repo(%{dist_version})
Requires: system-release(%{dist_version})
Conflicts: amazon-linux-repo-s3
Conflicts: system-release < 2022.0.20221019-2.amzn2022
RemovePathPostfixes: -cdn
%description -n amazon-linux-repo-cdn
Access to Amazon Linux repo via CloudFront

%package -n amazon-linux-repo-s3
Summary: Access to Amazon Linux repositories via S3
Provides: amazon-linux-repo
Provides: amazon-linux-repo(%{dist_version})
Requires: system-release(%{dist_version})
Conflicts: amazon-linux-repo-cdn
Conflicts: system-release < 2022.0.20221019-2.amzn2022
RemovePathPostfixes: -s3
%description -n amazon-linux-repo-s3
Access to Amazon Linux via S3

%package -n kernel-livepatch-repo-cdn
Summary: Access to Amazon Linux Kernel Livepatch repositories via CloudFront
Provides: kernel-livepatch-repo
Provides: kernel-livepatch-repo(%{system_release})
Requires: system-release(%{dist_version})
Conflicts: kernel-livepatch-repo-s3
Conflicts: system-release < 2022.0.20221101-1.amzn2022
RemovePathPostfixes: -cdn
%description -n kernel-livepatch-repo-cdn
Access to Amazon Linux Kernel Livepatch repo via CloudFront

%package -n kernel-livepatch-repo-s3
Summary: Access to Amazon Linux Kernel Livepatch repositories via S3
Provides: kernel-livepatch-repo
Provides: kernel-livepatch-repo(%{system_release})
Requires: system-release(%{dist_version})
Conflicts: kernel-livepatch-repo-cdn
Conflicts: system-release < 2022.0.20221101-1.amzn2022
RemovePathPostfixes: -s3
%description -n kernel-livepatch-repo-s3
Access to Amazon Linux Kernel Livepatch via S3

%prep

%build

%install
# Create /etc
mkdir -p %{buildroot}%{_sysconfdir}

# Create /usr/lib/system-release
install -d %{buildroot}%{_prefix}/lib
echo "%{product_family} release %{VERSION} (%{codename})" \
    > %{buildroot}%{_prefix}/lib/system-release
ln -s ../usr/lib/system-release %{buildroot}%{_sysconfdir}/system-release
ln -s ../usr/lib/system-release %{buildroot}%{_sysconfdir}/amazon-linux-release

# Write cpe to /etc/system-release-cpe
echo "%{cpe}" > %{buildroot}%{_prefix}/lib/system-release-cpe
ln -s ../usr/lib/system-release-cpe %{buildroot}%{_sysconfdir}/system-release-cpe
ln -s ../usr/lib/system-release-cpe %{buildroot}%{_sysconfdir}/amazon-linux-release-cpe

# -------------------------------------------------------------------------
# Definitions for /etc/os-release and for macros in macros.dist.  These
# macros are useful for spec files where distribution-specific identifiers
# are used to customize packages.

# Name of vendor / name of distribution. Typically used to identify where
# the binary comes from in --help or --version messages of programs.
# Examples: gdb.spec, clang.spec
%global dist_vendor Amazon Linux
%global dist_name   %{product_family}

# URL of the homepage of the distribution
# Example: gstreamer1-plugins-base.spec
%global dist_home_url https://aws.amazon.com/linux/amazon-linux-2023/

# URL of documentation
%global dist_doc_url https://docs.aws.amazon.com/linux/

# Vendor
%global dist_vendor AWS
%global dist_vendor_url https://aws.amazon.com/

# Support
%global dist_support_url https://aws.amazon.com/premiumsupport/

# Bugzilla / bug reporting URLs shown to users.
# Examples: gcc.spec
%global dist_bug_report_url https://github.com/amazonlinux/amazon-linux-%{major}

# debuginfod server, as used in elfutils.spec.
# Undefined for Amazon Linux
# %%global dist_debuginfod_url
# -------------------------------------------------------------------------


# Create /etc/os-release
cat << EOF >>%{buildroot}%{_prefix}/lib/os-release
NAME="%{dist_name}"
VERSION="%{dist_version}"
ID="%{dist_tag}"
ID_LIKE="fedora"
VERSION_ID="%{dist_version}"
PLATFORM_ID="platform:al%{major}"
PRETTY_NAME="%{dist_name} %{VERSION}"
ANSI_COLOR="0;33"
CPE_NAME="%{cpe}"
HOME_URL="%{dist_home_url}"
DOCUMENTATION_URL="%{dist_doc_url}"
SUPPORT_URL="%{dist_support_url}"
BUG_REPORT_URL="%{dist_bug_report_url}"
VENDOR_NAME="%{dist_vendor}"
VENDOR_URL="%{dist_vendor_url}"
SUPPORT_END="2028-03-15"
EOF

ln -s ../usr/lib/os-release %{buildroot}%{_sysconfdir}/os-release

# Create /etc/issue
echo "\S" > %{buildroot}%{_prefix}/lib/issue
echo "Kernel \r on an \m (\l)" >> %{buildroot}%{_prefix}/lib/issue
echo >> %{buildroot}%{_prefix}/lib/issue
ln -s ../usr/lib/issue %{buildroot}%{_sysconfdir}/issue

# Create /etc/issue.net
echo "\S" > %{buildroot}%{_prefix}/lib/issue.net
echo "Kernel \r on an \m (\l)" >> %{buildroot}%{_prefix}/lib/issue.net
ln -s ../usr/lib/issue.net %{buildroot}%{_sysconfdir}/issue.net

# copy GPG keys
mkdir -p -m 0755 %{buildroot}/etc/pki/rpm-gpg
install -m 0644 %{SOURCE30} %{buildroot}/etc/pki/rpm-gpg
install -m 0644 %{SOURCE31} %{buildroot}/etc/pki/rpm-gpg

# copy yum repos
mkdir -p -m 0755 %{buildroot}/etc/yum.repos.d
install -m 0644 %{SOURCE20} %{buildroot}/etc/yum.repos.d/amazonlinux.repo-cdn
install -m 0644 %{SOURCE22} %{buildroot}/etc/yum.repos.d/amazonlinux.repo-s3
install -m 0644 %{SOURCE24} %{buildroot}/etc/yum.repos.d/kernel-livepatch.repo-cdn
install -m 0644 %{SOURCE25} %{buildroot}/etc/yum.repos.d/kernel-livepatch.repo-s3

# Set up dnf release-notification plugin
mkdir -p -m 0755 %{buildroot}/etc/dnf/plugins
install -m 0644 %{SOURCE21} %{buildroot}/etc/dnf/plugins/release-notification.conf-cdn
install -m 0644 %{SOURCE23} %{buildroot}/etc/dnf/plugins/release-notification.conf-s3

# Set up the dist tag macros
install -d -m 755 %{buildroot}%{_rpmconfigdir}/macros.d
cat >> %{buildroot}%{_rpmconfigdir}/macros.d/macros.dist << EOF
# dist macros.

%%amzn %{major}
%%amzn%{major} 1
%%al_ver %{major}
%%fedora %{upstream_version}
%%fc%{upstream_version} 1
%%dist .%{dist_tag}%{major}xwalker
%%vendorzone amazon.
%%dist_vendor         %{dist_vendor}
%%dist_name           %{dist_name}
%%dist_home_url       %{dist_home_url}
%%dist_bug_report_url %{dist_bug_report_url}
EOF

# copy systemd presets
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-preset
install -m 0644 %{SOURCE10} %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE11} %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE12} %{buildroot}%{_prefix}/lib/systemd/user-preset/
# The same file is installed in two places with identical contents
install -m 0644 %{SOURCE13} %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE13} %{buildroot}%{_prefix}/lib/systemd/user-preset/

# Amazon Linux enables update-motd by default
install -m 0644 %{SOURCE14} %{buildroot}%{_prefix}/lib/systemd/system-preset/
# Amazon Linux enables amazon-ssm-agent by default
install -m 0644 %{SOURCE15} %{buildroot}%{_prefix}/lib/systemd/system-preset/
# Amazon Linux enables hibinit-agent by default
install -m 0644 %{SOURCE16} %{buildroot}%{_prefix}/lib/systemd/system-preset/
# Amazon Linux uses systemd-networkd
install -m 0644 %{SOURCE17} %{buildroot}%{_prefix}/lib/systemd/system-preset/

# Install MOTD scripts
install -d -m 755 %{buildroot}/etc/update-motd.d
install -m 755 %{SOURCE41} %{buildroot}/etc/update-motd.d/

# Install Amazon Linux motd banner
install -d -m 755 %{buildroot}%{_prefix}/lib/motd.d
install -m 755 %{SOURCE40} %{buildroot}%{_prefix}/lib/motd.d/30-banner

# create default dnf vars
mkdir -p -m 0755 %{buildroot}/etc/dnf/vars
echo "amazonaws.com" > %{buildroot}/etc/dnf/vars/awsdomain
echo "us-west-2" > %{buildroot}/etc/dnf/vars/awsregion
echo ".dualstack" > %{buildroot}/etc/dnf/vars/dualstack
echo "mirror.list" > %{buildroot}/etc/dnf/vars/mirrorlist

# install cloud-init configuration
mkdir -p -m 0755 %{buildroot}/etc/cloud/cloud.cfg.d
install -m 0644 %{SOURCE50} %{buildroot}/etc/cloud/cloud.cfg.d/

%files
%defattr(0644,root,root,0755)
%{_sysconfdir}/system-release
%{_sysconfdir}/amazon-linux-release
%{_prefix}/lib/system-release
%config(noreplace) %{_sysconfdir}/os-release
%config(noreplace) %{_prefix}/lib/os-release
%config %{_sysconfdir}/system-release-cpe
%config %{_sysconfdir}/amazon-linux-release-cpe
%config %{_prefix}/lib/system-release-cpe
%config(noreplace) %{_sysconfdir}/issue
%config(noreplace) %{_prefix}/lib/issue
%config(noreplace) %{_sysconfdir}/issue.net
%config(noreplace) %{_prefix}/lib/issue.net
%{_sysconfdir}/pki/rpm-gpg/
%{_sysconfdir}/pki/rpm-gpg/RPM-GPG-KEY-*
%dir /etc/yum.repos.d
%config(noreplace) /etc/dnf/vars/awsdomain
%config(noreplace) /etc/dnf/vars/awsregion
%config(noreplace) /etc/dnf/vars/dualstack
%config(noreplace) /etc/dnf/vars/mirrorlist
%config(noreplace) /etc/cloud/cloud.cfg.d/10_aws_dnfvars.cfg
%{_rpmconfigdir}/macros.d/macros.dist
%attr(0755,root,root) %{_prefix}/lib/motd.d/30-banner
%attr(0755,root,root) %{_sysconfdir}/update-motd.d/70-available-updates
%dir %{_prefix}/lib/systemd/system-preset/
%{_prefix}/lib/systemd/system-preset/85-display-manager.preset
%{_prefix}/lib/systemd/system-preset/90-default.preset
%{_prefix}/lib/systemd/system-preset/91-update-motd.preset
%{_prefix}/lib/systemd/system-preset/91-amazon-ssm-agent.preset
%{_prefix}/lib/systemd/system-preset/91-hibinit-agent.preset
%{_prefix}/lib/systemd/system-preset/91-systemd-networkd.preset
%{_prefix}/lib/systemd/system-preset/99-default-disable.preset
%dir %{_prefix}/lib/systemd/user-preset/
%{_prefix}/lib/systemd/user-preset/90-default-user.preset
%{_prefix}/lib/systemd/user-preset/99-default-disable.preset

%files -n amazon-linux-repo-cdn
%config %{_sysconfdir}/yum.repos.d/amazonlinux.repo-cdn
%config %{_sysconfdir}/dnf/plugins/release-notification.conf-cdn

%files -n amazon-linux-repo-s3
%config %{_sysconfdir}/yum.repos.d/amazonlinux.repo-s3
%config %{_sysconfdir}/dnf/plugins/release-notification.conf-s3

%files -n kernel-livepatch-repo-cdn
%config %{_sysconfdir}/yum.repos.d/kernel-livepatch.repo-cdn

%files -n kernel-livepatch-repo-s3
%config %{_sysconfdir}/yum.repos.d/kernel-livepatch.repo-s3

%changelog
* Mon Sep 9 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240916.0
- Amazon Linux 2023.5.20240916.0

* Tue Aug 27 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240903.0
- Amazon Linux 2023.5.20240903.0

* Tue Aug 13 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240819.0
- Amazon Linux 2023.5.20240819.0

* Tue Jul 30 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240805.0
- Amazon Linux 2023.5.20240805.0

* Thu Jul 25 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240730.0
- Amazon Linux 2023.5.20240730.0

* Mon Jul 15 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240722.0
- Amazon Linux 2023.5.20240722.0

* Thu Jun 27 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240708.1
- Amazon Linux 2023.5.20240708.1

* Thu Jun 18 2024 Chris Bilbo <cbilbo@amazon.com> - 2023.5.20240701.0
- Amazon Linux 2023.5.20240701.0
- Updating release notification plugin conf to control which s3 endpoint is used

* Wed Jun 18 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.5.20240624.0
- Amazon Linux 2023.5.20240624.0

* Fri May 24 2024 Ken Reeves <kenr@amazon.com> - 2023.4.20240611.1
- Amazon Linux 2023.4.20240611.1

* Thu May 23 2024 Ken Reeves <kenr@amazon.com> - 2023.4.20240611.0
- Amazon Linux 2023.4.20240611.0
- Added support for using dnf vars to control which s3 endpoint is used for amazonlinux package repo.

* Wed May 22 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.4.20240528.0
- Amazon Linux 2023.4.20240528.0

* Wed May 8 2024 Christopher R. Miller <milrchr@amazon.com> - 2023.4.20240513.1
- Amazon Linux 2023.4.20240513.1

* Tue Apr 16 2024 Robert Nickel <halfdime@amazon.com> - 2023.4.20240416.0
- Amazon Linux 2023.4.20240416.0

* Mon Apr 01 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.4.20240401.0
- Amazon Linux 2023.4.20240401.0

* Tue Mar 19 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.4.20240319.1
- Modify cpe definition

* Tue Mar 19 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.4.20240319.0
- Amazon Linux 2023.4.20240319.0

* Tue Mar 12 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240312.0
- Amazon Linux 2023.3.20240312.0

* Mon Mar 04 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240304.0
- Amazon Linux 2023.3.20240304.0

* Mon Feb 19 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240219.0
- Amazon Linux 2023.3.20240219.0

* Mon Feb 05 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240205.0
- Amazon Linux 2023.3.20240205.0

* Wed Jan 31 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240131.0
- Amazon Linux 2023.3.20240131.0

* Mon Jan 22 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240122.0
- Amazon Linux 2023.3.20240122.0

* Wed Jan 17 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240117.0
- Amazon Linux 2023.3.20240117.0

* Mon Jan 08 2024 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20240108.0
- Amazon Linux 2023.3.20240108.0

* Mon Dec 18 2023 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20231218.0
- Amazon Linux 2023.3.20231218.0

* Mon Dec 11 2023 Harish Senthilkumar <harishxr@amazon.com> - 2023.3.20231211.0
- Amazon Linux 2023.3.20231211.0

* Mon Nov 13 2023 Sonia Xu <sonix@amazon.com> - 2023.2.20231113.1
- Correct AL23 EOL support date in /etc/os-release file

* Mon Nov 13 2023 Harish Senthilkumar <harishxr@amazon.com> - 2023.2.20231113.0
- Amazon Linux 2023.2.20231113.0

* Mon Oct 30 2023 Harish Senthilkumar <harishxr@amazon.com> - 2023.2.20231030.1
- Amazon Linux 2023.2.20231030.1

* Thu Oct 26 2023 Harish Senthilkumar <harishxr@amazon.com> - 2023.2.20231026.0
- Amazon Linux 2023.2.20231026.0

* Wed Oct 18 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.2.20231018.0
- Amazon Linux 2023.2.20231018.0

* Mon Oct 16 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.2.20231016.0
- Amazon Linux 2023.2.20231016.0

* Mon Oct 11 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.2.20231011.0
- Amazon Linux 2023.2.20231011.0

* Wed Oct 04 2023 Mansi Jaitly <mjaitly@amazon.com> - 2023.2.20231002.1
- Update RPM-GPG-KEY-amazon-linux-2023 with public key with key flags

* Mon Oct 02 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.2.20231002.0
- Amazon Linux 2023.2.20231002.0

* Wed Sep 20 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.2.20230920.0
- Amazon Linux 2023.2.20230920.0

* Tue Sep 12 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230912.0
- Amazon Linux 2023.1.20230912.0

* Wed Sep 06 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230906.0
- Amazon Linux 2023.1.20230906.0

* Fri Aug 25 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230825.0
- Amazon Linux 2023.1.20230825.0

* Tue Aug 08 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230809.0
- Amazon Linux 2023.1.20230809.0

* Wed Jul 25 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230725.0
- Amazon Linux 2023.1.20230725.0

* Wed Jul 19 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230719.0
- Amazon Linux 2023.1.20230719.0

* Wed Jul 05 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230705.0
- Amazon Linux 2023.1.20230705.0

* Thu Jun 29 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230629.0
- Amazon Linux 2023.1.20230629.0

* Wed Jun 28 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.1.20230628.0
- Amazon Linux 2023.1.20230628.0

* Wed Jun 14 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230614.0
- Amazon Linux 2023.0.20230614.0

* Wed Jun 07 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230607.0
- Amazon Linux 2023.0.20230607.0

* Wed May 17 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230517.0
- Amazon Linux 2023.0.20230517.0

* Wed May 03 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230503.0
- Amazon Linux 2023.0.20230503.0

* Wed Apr 19 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230419.0
- Amazon Linux 2023.0.20230419.0

* Wed Mar 29 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230329.0
- Amazon Linux 2023.0.20230329.0

* Wed Mar 22 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230322.0
- Amazon Linux 2023.0.20230322.0

* Wed Mar 15 2023 Stewart Smith <trawets@amazon.com> - 2023.0.20230315.1
- Update presets for Amazon Linux defaults for systemd-networkd
- Remove any explicit preset for NetworkManager, as AL2023 doesn't ship it
- Disable dnf-makecache.timer as default enabled
- Disable abrt services in presets, not shipped in AL2023
- Disable service adding Fedora repos to flatpak in presets

* Wed Mar 15 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230315.0
- Amazon Linux GA 2023.0.20230315.0

* Wed Mar 08 2023 Nikhil Dikshit <nikhildi@amazon.com> - 2023.0.20230308.0
- Amazon Linux 2023.0.20230308.0

* Mon Feb 20 2023 Noah Meyerhans <nmeyerha@amazon.com> - 2023.0.20230222.0
- Amazon Linux 2023.0.20230222.0

* Fri Feb  3 2023 Noah Meyerhans <nmeyerha@amazon.com> - 2023.0.20230206.0
- Amazon Linux 2023.0.20230206.0

* Mon Dec 12 2022 Noah Meyerhans <nmeyerha@amazon.com> - 2023.0.20221212.0
- Amazon Linux 2023.0.20221212.0

* Wed Dec 07 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221207.0
- Amazon Linux 2022.0.20221207.0

* Thu Nov 03 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221103.0
- Amazon Linux 2022.0.20221103.0

* Wed Nov 02 2022 Samuel Mendoza-Jonas <samjonas@amazon.com>  - 2022.0.20221102.1
- Add repos for kernel livepatching

* Wed Nov 02 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221102.0
- Amazon Linux 2022.0.20221102.0

* Tue Nov 01 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221101.0
- Amazon Linux 2022.0.20221101.0

* Thu Oct 20 2022 Dirk Harms-Merbitz <dhm@amazon.com> - 2022.0.20221020.0
- Added $basearch to dedbuginfo URL in repo-cdn

* Wed Oct 19 2022 Dirk Harms-Merbitz <dhm@amazon.com> - 2022.0.20221019.2
- Making repos require correct version of system-release

* Wed Oct 19 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221019.1
- Use us-west-2 to be the default region

* Wed Oct 19 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221019.0
- Amazon Linux 2022.0.20221019.0
- dhm: Created sub packages Amazon Linux CDN repo and Amazon Linux S3 repo

* Thu Oct 13 2022 Stewart Smith <trawets@amazon.com> - 2022.0.20221012.1
- Add a SUPPORT_END to /etc/os-release
- Enable update-motd.timer by default
- Use Amazon Linux ASCII-art logo for motd
- Enable Amazon SSM Agent service by default (mirroring AL2 behavior)
- Enable hibinit-agent service by default (mirroring AL2 behavior)

* Wed Oct 12 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20221012.0
- Amazon Linux 2022.0.20221012.0

* Wed Sep 28 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220928.0
- Amazon Linux 2022.0.20220928.0

* Wed Sep 21 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220921.0
- Amazon Linux 2022.0.20220921.0

* Fri Sep 13 2022 Kent Forschmiedt <kentf@amazon.com> - 2022.0.20220914.2
- Add new release info to MOTD

* Fri Sep 09 2022 Cameron Quinn <ctq@amazon.com> - 2022.0.20220914.1
- Amazon Linux 2022.0.20220914.0

* Wed Aug 31 2022 Amit Shah <aams@amzn.com> - 2022.0.20220831.1
- Backport new macros.dist macros to ease downstream spec divergences
- Replace Amazon Linux home URL to one the canonical one
- Add a bug report URL to /etc/os-release

* Wed Aug 31 2022 Cameron Quinn <ctq@amazon.com> - 2022.0.20220831.0
- Amazon Linux 2022.0.20220831.0

* Wed Aug 24 2022 Cameron Quinn <ctq@amazon.com> - 2022.0.20220824.0
- Amazon Linux 2022.0.20220824.0

* Wed Aug 17 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220817.0
- Amazon Linux 2022.0.20220817.0

* Wed Aug 10 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220810.0
- Amazon Linux 2022.0.20220810.0

* Thu Jul 28 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220728.0
- Amazon Linux 2022.0.20220728.0

* Tue Jul 19 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220719.0
- Amazon Linux 2022.0.20220719

* Tue Jun 28 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220628.0
- Amazon Linux 2022.0.20220628

* Tue May 31 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220531.0
- Amazon Linux 2022.0.20220531

* Tue May 17 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220518.0
- Amazon Linux 2022.0.20220518

* Wed May  4 2022 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20220504.0
- Amazon Linux 2022.0.20220504

* Tue Apr 19 2022 Frederick Lefebvre <fredlef@amazon.com> - 2022.0.20220419.2
- Remove explicit dependency on /usr/bin/bash

* Tue Apr 19 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220419.0
- Amazon Linux 2022.0.20220419

* Tue Mar 15 2022 Sonia Xu <sonix@amazon.com> - 2022.0.20220315.0
- Amazon Linux 2022.0.20220315

* Mon Mar 14 2022 Sonia Xu <sonix@amazon.com> - 2022.0.20220314.0
- Amazon Linux 2022.0.20220314

* Mon Mar 07 2022 Sonia Xu <sonix@amazon.com> - 2022.0.20220308.0
- Amazon Linux 2022.0.20220308

* Wed Mar 02 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220302.0
- Amazon Linux 2022.0.20220302

* Tue Feb 22 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220222.0
- Amazon Linux 2022.0.20220222

* Tue Feb 15 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220215.0
- Amazon Linux 2022.0.20220215

* Fri Feb 11 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220204.1
- Configure source repos by default

* Fri Feb 04 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220204.0
- Amazon Linux 2022.0.20220204

* Wed Feb 02 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220202.0
- Amazon Linux 2022.0.20220202

* Mon Jan 31 2022 Nikhil Dikshit <nikhildi@amazon.com> - 2022.0.20220131.0
- Amazon Linux 2022.0.20220131

* Tue Jan 25 2022 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20220125.0
- Amazon Linux 2022.0.20220125

* Wed Dec 22 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211222.0
- Amazon Linux 2022.0.20211222

* Mon Dec 20 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211220.0
- Amazon Linux 2022.0.20211220

* Fri Dec 17 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211217.0
- Amazon Linux 2022.0.20211217

* Fri Dec 10 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211210.0
- Amazon Linux 2022.0.20211210

* Wed Dec  1 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211201.0
- Amazon Linux 2022.0.20211201

* Wed Nov 24 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211124.0
- Amazon Linux 2022.0.20211124

* Tue Nov 23 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211123.0
- Amazon Linux 2022.0.20211123

* Mon Nov 22 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211122.0
- Amazon Linux 2022.0.20211122

* Fri Nov 19 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211119.0
- Amazon Linux 2022.0.20211119

* Thu Nov 18 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211118.0
- Amazon Linux 2022.0.20211118

* Wed Nov 17 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211117.0
- Amazon Linux 2022.0.20211117
- Enable gpgcheck on repositories

* Tue Nov 16 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211116.1
- Utilize pam_motd for static parts of motd

* Tue Nov 16 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211116.0
- Amazon Linux 2022.0.20211116

* Mon Nov 15 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211115.0
- Amazon Linux 2022.0.20211115
- Add debuginfo repository

* Fri Nov 12 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211112.0
- Amazon Linux 2022.0.20211112

* Thu Nov 11 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211111.0
- Amazon Linux 2022.0.20211111

* Wed Nov 10 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211110.0
- Amazon Linux 2022.0.20211110

* Tue Nov  9 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211109.0
- Amazon Linux 2022.0.20211109

* Mon Nov  8 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211108.0
- Amazon Linux 2022.0.20211108

* Fri Nov  5 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211105.0
- Amazon Linux 2022.0.20211105
- Correct URL for all regions for release-notification dnf plugin

* Thu Nov  4 2021 Malcolm Inglis <miinglis@amazon.com> - 2022.0.20211104.0
- Amazon Linux 2022.0.20211104

* Wed Nov  3 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211103.0
- Amazon Linux 2022.0.20211103

* Tue Nov  2 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211102.0
- Amazon Linux 2022.0.20211102

* Mon Nov  1 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211101.0
- Amazon Linux 2022.0.20211101

* Fri Oct 29 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211029.0
- Amazon Linux 2022.0.20211029
- Enable update-motd service by default
- update motd for tech preview

* Thu Oct 28 2021 Jeremiah Mahler <jmmahler@amazon.com> - 2022.0.20211028.1
- Add %{vendorzone} macro so chronyd gets the right ntp server name

* Thu Oct 28 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211028.0
- Amazon Linux 2022.0.20211028

* Wed Oct 27 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211027.0-1
- system-release should own /etc/yum.repos.d

* Wed Oct 27 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211027.0
- Amazon Linux 2022.0.20211027

* Tue Oct 26 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211026.0-1
- Install DNF Release Notification plugin configuration

* Tue Oct 26 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211026.0
- Amazon Linux 2022.0.20211026

* Mon Oct 25 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211025.0
- Amazon Linux 2022.0.20211025

* Thu Oct 21 2021 Jeremiah Mahler <jmmahler@amazon.com> - 2022.0.20211021.2
- Include user presets

* Wed Oct 20 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211021.1
- Amazon Linux 2022.0.20211021

* Wed Oct 20 2021 Jeremiah Mahler <jmmahler@amazon.com> - 2022.0.20211019.1
- Add default-disable preset

* Tue Oct 19 2021 Stewart Smith <trawets@amazon.com> - 2022.0.20211019.0
- 2022-0.20211019.0
- Point to production repo URLs and s/yum/dnf/ for variables
- use full version number as releasever

* Mon Sep 27 2021 Sai Harsha <ssuryad@amazon.com> - 2022-0.20210927.0
- Change dist tag to amzn2022

* Thu Sep  9 2021 Benjamin Herrenschmidt <benh@amazon.com> - 2022-0.20210909.1
- Fix macros.dist

* Thu Sep  9 2021 Benjamin Herrenschmidt <benh@amazon.com> - 2022-0.20210909.0
- Force rebuild

* Tue Sep  7 2021 Robert Nickel <halfdime@amazon.com> - 2022-0.20210907.0
- Initial release of system files.
